/**
 *	drupal JS helper functions
 *	created by: Steve McKenzie - Raincity Studios (www.raincitystudios.com) - 14-03-06
 */

/*
 *	grabs $_GET variables (query string)
 */
function _get(name) {
	get_string = document.location.search;         
	return_value = '';
	
	do {
		name_index = get_string.indexOf(name + '=');
		
		if (name_index != -1) {
			get_string = get_string.substr(name_index + name.length + 1, get_string.length - name_index);
			end_of_value = get_string.indexOf('&');
			
			if(end_of_value != -1) {
				value = get_string.substr(0, end_of_value);
			} else {
				value = get_string;
			}
			
			if(return_value == '' || value == '')
			return_value += value;
			else
			return_value += ', ' + value;
		}
	} while(name_index != -1)
	
	space = return_value.indexOf('+');
	while (space != -1) { 
		return_value = return_value.substr(0, space) + ' ' + 
		return_value.substr(space + 1, return_value.length);
		space = return_value.indexOf('+');
	}
  return(return_value);        
}

/**
 * add an even to an object
 */
function add_event(elm, evType, fn, useCapture) {
  if (elm.addEventListener){
    elm.addEventListener(evType, fn, useCapture);
    return true;
  } else if (elm.attachEvent){
    var r = elm.attachEvent("on"+evType, fn);
    return r;
  }
}

/**
 * append a form element to any element
 */
function append_form_element(node, type, attributes, options, match_value) {
	var el;
	
	switch(type) {
		case "select":
			el = document.createElement(type);

			for (var o in options) {
				if (typeof(options[o]) != "function") {
					el.options[el.options.length] = new Option(options[o], o);
				}
			}
			
			if(match_value) {
				for(var m in options) {
					if(options[m] == match_value) {
						el.selectedIndex = m;
					}
				}
			}
			
			break;
			
		case "textarea":
			el = document.createElement(type);
			el.innerHTML = match_value;
			break;
			
		case "fieldset":
			el = document.createElement(type);
			
			if(options['legend']) {
				var legend = document.createElement('legend');
				legend.createTextNode(options['legend']);
				el.appendChild(legend);
			}
			
			el.value = match_value;
			break;
			
		default:
			el = document.createElement('input');
			el.type = type;
			
			if (typeof(match_value) == "array") {
				for (var opt in match_value) {
					if (match_value[opt] == el.value) {
						el.value = match_value[opt];
					}
				}
			} else {
				el.value = match_value;
			}
			break;
	}
	
	for (var i in attributes) {
		if (typeof(attributes[i]) != "object" && typeof(attributes[i]) != "function") {
			var attr = document.createAttribute(i);
			attr.value = attributes[i];
			el.setAttributeNode(attr);
		}
	}
	
	return node.appendChild(el);
}

/**
 *	removes all spaces around words ?
 */
function clear_spaces(str) {
	return str.replace(/(\s+$)|(^\s+)/g, '');
}

function db_count(table, index, match) {
	// we need both the match value and an index which is actually the column name
	if (typeof(cols) == "array") {
		for (var m = 0; m < match.length; m++) {
			match_str += match[m] +"||||";
			index_str += index[m] +"||||";
		}
	} else {
		match_str = match;
		index_str = index;
	}
	
	var post = "table="+ table +'&match='+ match_str +'&index='+ index_str;
	var a = new ajax(drupal_get_path('url', 'moo') +"/ajax/db_count", { postBody: post, async: 'false' });
	var result = a.transport.responseXML.getElementsByTagName("item");
	
	return result[0].getAttribute('count');
}

/**
 *	get a row from a database table
 */
function db_row(table, cols, index, match, async) {
	var cols_str, match_str, index_str;
	
	if (typeof(cols) == "array") {
		// make strings that we can explode in PHP
		for (var c = 0; c < cols.length; c++) {
			cols_str += cols[c] +"||||";
		}
	} else {
		cols_str = cols;
	}
	
	// we need both the match value and an index which is actually the column name
	if (typeof(cols) == "array") {
		for (var m = 0; m < match.length; m++) {
			match_str += match[m] +"||||";
			index_str += index[m] +"||||";
		}
	} else {
		match_str = match;
		index_str = index;
	}
	
	// posts for PHP
	var post_body = 'table='+ table +'&cols='+ cols_str +'&match='+ match_str +'&index='+ index_str;
	var a = new ajax(drupal_get_path("url", "moo")+ "/ajax/db_row", {async: ((async) ? async : 'false'), postBody: post_body});
	var items = a.transport.responseXML.getElementsByTagName("items");
	var row = Array();

	// create a nice array for output
	for (var i = 0; i < items.length; i++) {
		var col_index = cols[i];
		row[col_index] = items[i].firstChild.nodeValue;	
	}
		
	return row;
}

function arg(index) {
	var q = _get('q');
	
	if (q) {
		var args = q.split("/");
	} else {
		var args = window.location.pathname.split("/");
	}
	
	if (!args[0]) {
		args.splice(0,1);
	}
	
	if (index || index == 0) {
		return args[index];
	} else {
		return args;
	}
}

function drupal_get_path(type, name) {
	var query;
	
	if (type == "url") {
		query = name;		
	}	else {
		query = type +"s/"+ name;
	}
	
	if (_get('q')) {
		var url =  "?q="+ query
	} else {
		var url = query;
	}

	return base_url +"/" + url;
}

/**
 * get a variable from Drupal variable_get (give variable_name, returns value) 
 * or pass an array of variable_names and default_values
 */
function variable_get(variable_name, default_value, async) {
	var post_body = "";
	
	if (typeof(variable_name) == "object") {
		for (var i = 0; i < variable_name.length; i++) {
			post_body += variable_name[i] +"="+ default_value[i] + ((i < (variable_name.length -1)) ? "&" : "");
		}
	} else {
		post_body = variable_name +"="+ default_value;	
	}
	
	var ajax_url = drupal_get_path("url", "moo") +"/ajax/get";
	var a = new ajax(ajax_url, {postBody: post_body, async: ((async) ? async : 'false')});
	var xml = a.transport.responseXML;
	var items = xml.getElementsByTagName("item");
	var output = new Array();
	
	if (items.length > 1) {
		for (var i = 0; i < items.length; i++) {
			var index = items[i].getAttribute("id");
			output[index] = items[i].firstChild.nodeValue;
		}
	} else {
		output = items[0].firstChild.nodeValue;	
	}
	
	return output;
}